CacheStore class abstract

Cache storage abstraction

Implementers

Constructors

CacheStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanup(DateTime before) Future<void>
clear() Future<void>
delete(String key) Future<void>
get<T>(String key) Future<CachedResponse<T>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set<T>(String key, CachedResponse<T> response) Future<void>
size() Future<int>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited