FlintDbQuery class
Constructors
-
FlintDbQuery({List<
String> select = const [], FlintDbFilter? filter, List<FlintDbOrder> order = const [], int? limit, int? offset, String? cursor}) -
const
-
FlintDbQuery.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cursor → String?
-
final
- filter → FlintDbFilter?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
final
- offset → int?
-
final
-
order
→ List<
FlintDbOrder> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
select
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited