FlintResponseType enum

Enum representing the type of response returned by the Flint client.

Inheritance
Available extensions

Values

json → const FlintResponseType

Response is in JSON format

text → const FlintResponseType

Response is plain text

file → const FlintResponseType

Response is a file

unknown → const FlintResponseType

Response type is unknown

html → const FlintResponseType

Response is HTML

binary → const FlintResponseType

Response is binary data

stream → const FlintResponseType

stream, // ADD this line

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FlintResponseType>
A constant List of the values in this enum, in order of their declaration.