OpenAIResponse class

Constructors

OpenAIResponse({String? text, List<String>? messages, List<List<double>>? embeddings, Map<String, dynamic>? usage, Map<String, dynamic>? raw})
OpenAIResponse.fromJson(dynamic json)
Parse any OpenAI API response into a structured model
factory

Properties

embeddings List<List<double>>?
final
hashCode int
The hash code for this object.
no setterinherited
messages List<String>?
final
raw Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
usage Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Human-readable summary
override

Operators

operator ==(Object other) bool
The equality operator.
inherited