ResponseSerializerInput class

Constructors

ResponseSerializerInput({required HttpClientResponse response, required List<int> bytes, Uri? requestUrl, String? baseUrl, String? saveFilePath, RequestContext? context})
const

Properties

baseUrl String?
final
bytes List<int>
final
context RequestContext?
final
hashCode int
The hash code for this object.
no setterinherited
requestUrl Uri?
final
response HttpClientResponse
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveFilePath String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited