FlintDatabaseClient class

Constructors

FlintDatabaseClient({required FlintClient client, String basePath = '/db/v1'})

Properties

auth FlintDbAuthClient
latefinal
basePath String
final
client FlintClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

from(String resource) FlintDbResourceClient
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String resource, FlintDbQuery query) Future<FlintDbResult<List<Map<String, dynamic>>>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodeRows(Map<String, dynamic> json) FlintDbResult<List<Map<String, dynamic>>>