FlintWebSocketClient class

Constructors

FlintWebSocketClient(String url, {Map<String, dynamic>? params, String? token, AuthTokenProvider? tokenProvider, bool debug = false, bool sendTokenAsQuery = false, String queryTokenKey = 'token', Duration heartbeatInterval = const Duration(seconds: 25), Duration pongTimeout = const Duration(seconds: 30), int maxReconnectAttempts = 5})

Properties

debug bool
final
hashCode int
The hash code for this object.
no setterinherited
heartbeatInterval Duration
final
isConnected bool
no setter
maxReconnectAttempts int
final
params Map<String, dynamic>?
final
pongTimeout Duration
final
queryTokenKey String
final
queuedMessageCount int
no setter
reconnectAttempt int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendTokenAsQuery bool
final
state WebSocketConnectionState
no setter
token String?
no setter
url String
final

Methods

close([int code = 1000, String? reason]) → void
connect() Future<void>
dispose() → void
emit(String event, dynamic data) → void
join(String room) → void
leave(String room) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String event, [Function? handler]) → void
on(String event, dynamic handler(dynamic data)) → void
reconnect() Future<void>
setToken(String? token) → void
setTokenProvider(AuthTokenProvider? provider) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited