StatusCodeConfig class

Constructors

StatusCodeConfig({Set<int> successCodes = const {200, 201, 202, 204}, Set<int> errorCodes = const {400, 401, 402, 403, 404, 405, 408, 409, 410, 422, 429, 500, 501, 502, 503, 504}, Set<int> redirectCodes = const {301, 302, 303, 304, 307, 308}, Set<int> clientErrorCodes = const {400, 401, 402, 403, 404, 405, 408, 409, 410, 422, 429}, Set<int> serverErrorCodes = const {500, 501, 502, 503, 504}})
const

Properties

clientErrorCodes Set<int>
final
errorCodes Set<int>
final
hashCode int
The hash code for this object.
no setterinherited
redirectCodes Set<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverErrorCodes Set<int>
final
successCodes Set<int>
final

Methods

isClientError(int statusCode) bool
isError(int statusCode) bool
isRedirect(int statusCode) bool
isServerError(int statusCode) bool
isSuccess(int statusCode) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited