HuggingFaceResponse class
Constructors
-
HuggingFaceResponse({String? generatedText, List? embeddings, List? labels, List? scores, Map<
String, dynamic> ? raw}) - HuggingFaceResponse.fromJson(dynamic json)
-
Parse API JSON response into structured data
factory
Properties
- embeddings → List?
-
final
- generatedText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labels → List?
-
final
-
raw
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scores → List?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Convenience getter for quick printing
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited