RequestContext class
Mutable request-scoped state passed across client components.
Constructors
Properties
- attempt ↔ int
-
getter/setter pair
- cacheHit ↔ bool
-
getter/setter pair
- cacheKey ↔ String?
-
getter/setter pair
- correlationId → String
-
final
- endedAt ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
final
- method → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt ↔ DateTime?
-
getter/setter pair
- totalDuration ↔ Duration?
-
getter/setter pair
- url → Uri
-
final
Methods
-
getValue<
T> (String key) → T? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
String key, dynamic value) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited