FlintError class

Implemented types

Constructors

FlintError(String message, {int? statusCode, dynamic originalException, dynamic data, Uri? url, String? method, FlintErrorKind? kind, Duration? retryAfter, DateTime? timestamp})
FlintError.cancelled({String message = 'Request cancelled', Uri? url, String? method, dynamic originalException})
factory
FlintError.fromException(dynamic exception, {int? statusCode, Uri? url, String? method})
factory

Properties

data → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
no setter
isClientError bool
no setter
isNetworkError bool
no setter
isRateLimit bool
no setter
isRetryable bool
no setter
isServerError bool
no setter
isTimeout bool
no setter
kind FlintErrorKind
final
message String
final
method String?
final
originalException → dynamic
final
retryAfter Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final
timestamp DateTime
final
url Uri?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cancelledStatusCode → const int