FlintResponse<T> class
Constructors
-
FlintResponse({required int statusCode, T? data, FlintResponseType type = FlintResponseType.unknown, Map<
String, String> ? headers, Uri? url, String? method, DateTime? timestamp, Duration? duration, StatusCodeConfig? statusConfig}) -
FlintResponse.error(FlintError error, {Map<
String, String> ? headers, String? method, Duration? duration, StatusCodeConfig? statusConfig})
Properties
- data → T?
-
final
- duration → Duration?
-
final
- error → FlintError?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
final
- isBinary → bool
-
no setter
- isClientError → bool
-
no setter
- isError → bool
-
final
- isFile → bool
-
no setter
- isHtml → bool
-
no setter
- isJson → bool
-
no setter
- isRedirect → bool
-
no setter
- isServerError → bool
-
no setter
- isSuccess → bool
-
no setter
- isText → bool
-
no setter
- method → String?
-
final
- requireData → T
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
- statusConfig → StatusCodeConfig
-
final
- success → bool
-
final
- timestamp → DateTime
-
final
- type → FlintResponseType
-
final
- url → Uri?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
throwIfError(
) → FlintResponse< T> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited